@@ -1,7 +1,7 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem, Drive
+from netbox_storage.models import Filesystem, Drive, LinuxVolume
 
 
 #
@@ -18,6 +18,23 @@ class NestedFilesystemSerializer(WritableNestedSerializer):
         fields = ["id", "url", "display", "filesystem"]
 
 
+#
+# LinuxVolume
+#
+
+class NestedLinuxVolumeSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:linuxvolume-detail"
+    )
+
+    class Meta:
+        model = LinuxVolume
+        fields = ["id", "url", "display", "vg_name"]
+
+
+#
+# Drive
+#
 class NestedDriveSerializer(WritableNestedSerializer):
     url = serializers.HyperlinkedIdentityField(
         view_name="plugins-api:netbox_storage-api:drive-detail"
