@@ -5,7 +5,7 @@ from netbox_storage.api.views import (
     DriveViewSet,
     FilesystemViewSet,
     LinuxVolumeViewSet,
-    WindowsVolumeViewSet,
+    LinuxVolumeDriveViewSet,
 )
 
 router = NetBoxRouter()
@@ -14,6 +14,6 @@ router.APIRootView = NetboxStorageRootView
 router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
 router.register("linuxvolume", LinuxVolumeViewSet)
-router.register("windowsvolume", WindowsVolumeViewSet)
+router.register("linuxvolumedrive", LinuxVolumeDriveViewSet)
 
 urlpatterns = router.urls
