@@ -81,39 +81,6 @@ class Migration(migrations.Migration):
                 "ordering": ("lv_name", "id"),
             },
         ),
-        migrations.CreateModel(
-            name="WindowsVolume",
-            fields=[
-                ("created", models.DateTimeField(auto_now_add=True, null=True)),
-                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
-                (
-                    "custom_field_data",
-                    models.JSONField(
-                        blank=True,
-                        default=dict,
-                        encoder=utilities.json.CustomFieldJSONEncoder
-                    ),
-                ),
-                ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("drive_name", models.CharField(max_length=255)),
-                ("fs",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_windows',
-                                   to='netbox_storage.filesystem')),
-                (
-                    "drives",
-                    models.ManyToManyField(
-                        blank=True, related_name="drives", to="netbox_storage.drive"
-                    ),
-                ),
-                ('virtual_machine',
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name='drive_volume', to='virtualization.virtualmachine')),
-                ("description", models.CharField(max_length=255)),
-            ],
-            options={
-                "ordering": ("drive_name", "id"),
-            },
-        ),
         migrations.CreateModel(
             name="LinuxVolumeDrive",
             fields=[
@@ -130,7 +97,7 @@ class Migration(migrations.Migration):
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
                 ("allocation", models.PositiveIntegerField()),
                 ("drive",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='drive',
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='drive_linuxvolume',
                                    to='netbox_storage.drive')),
                 ("linuxvolume",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='linuxvolume',
