@@ -108,10 +108,6 @@ class LinuxVolume(NetBoxModel):
             "description",
         ]
 
-    prerequisite_models = (
-        'dcim.platform'
-    )
-
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
 
@@ -122,46 +118,11 @@ class LinuxVolume(NetBoxModel):
         ordering = ("vg_name", "lv_name", "path")
 
 
-class WindowsVolume(NetBoxModel):
-    drive_name = models.CharField(
-        max_length=255,
-    )
-    fs = models.ForeignKey(
-        Filesystem,
-        on_delete=models.CASCADE,
-        related_name="fs_windows",
-        verbose_name="Filesystem",
-    )
-    description = models.CharField(
-        max_length=255,
-        blank=True,
-    )
-
-    clone_fields = [
-            "drive_name",
-            "fs",
-            "description",
-        ]
-
-    prerequisite_models = (
-        'dcim.platform'
-    )
-
-    def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:windowsvolume", kwargs={"pk": self.pk})
-
-    def __str__(self):
-        return f"Name: {self.drive_name} filesystem: {self.fs}"
-
-    class Meta:
-        ordering = ("drive_name", "fs")
-
-
 class LinuxVolumeDrive(NetBoxModel):
     drive = models.ForeignKey(
         Drive,
         on_delete=models.CASCADE,
-        related_name='drive',
+        related_name='drive_linuxvolume',
     )
     linuxvolume = models.ForeignKey(
         LinuxVolume,
