@@ -2,7 +2,7 @@ from django.urls import path
 
 from netbox.views.generic import ObjectChangeLogView
 
-from netbox_storage.models import Drive, Filesystem, LinuxVolume, WindowsVolume
+from netbox_storage.models import Drive, Filesystem, LinuxVolume, LinuxVolumeDrive
 from netbox_storage.views import (
     # Drive View
     DriveListView,
@@ -28,14 +28,14 @@ from netbox_storage.views import (
     LinuxVolumeBulkImportView,
     LinuxVolumeBulkEditView,
     LinuxVolumeBulkDeleteView,
-    # WindowsVolume
-    WindowsVolumeListView,
-    WindowsVolumeView,
-    WindowsVolumeDeleteView,
-    WindowsVolumeEditView,
-    WindowsVolumeBulkImportView,
-    WindowsVolumeBulkEditView,
-    WindowsVolumeBulkDeleteView,
+    # LinuxVolume
+    LinuxVolumeDriveListView,
+    LinuxVolumeDriveView,
+    LinuxVolumeDriveDeleteView,
+    LinuxVolumeDriveEditView,
+    LinuxVolumeDriveBulkImportView,
+    LinuxVolumeDriveBulkEditView,
+    LinuxVolumeDriveBulkDeleteView,
 )
 
 app_name = "netbox_storage"
@@ -95,18 +95,18 @@ urlpatterns = [
     #
     # LinuxVolume urls
     #
-    path("windowsvolume/", WindowsVolumeListView.as_view(), name="windowsvolume_list"),
-    path("windowsvolume/add/", WindowsVolumeEditView.as_view(), name="windowsvolume_add"),
-    path("windowsvolume/import/", WindowsVolumeBulkImportView.as_view(), name="windowsvolume_import"),
-    path("windowsvolume/edit/", WindowsVolumeBulkEditView.as_view(), name="windowsvolume_bulk_edit"),
-    path("windowsvolume/delete/", WindowsVolumeBulkDeleteView.as_view(), name="windowsvolume_bulk_delete"),
-    path("windowsvolume/<int:pk>/", WindowsVolumeView.as_view(), name="windowsvolume"),
-    path("windowsvolume/<int:pk>/edit/", WindowsVolumeEditView.as_view(), name="windowsvolume_edit"),
-    path("windowsvolume/<int:pk>/delete/", WindowsVolumeDeleteView.as_view(), name="windowsvolume_delete"),
+    path("linuxvolumedrive/", LinuxVolumeDriveListView.as_view(), name="linuxvolumedrive_list"),
+    path("linuxvolumedrive/add/", LinuxVolumeDriveEditView.as_view(), name="linuxvolumedrive_add"),
+    path("linuxvolumedrive/import/", LinuxVolumeDriveBulkImportView.as_view(), name="linuxvolumedrive_import"),
+    path("linuxvolumedrive/edit/", LinuxVolumeDriveBulkEditView.as_view(), name="linuxvolumedrive_bulk_edit"),
+    path("linuxvolumedrive/delete/", LinuxVolumeDriveBulkDeleteView.as_view(), name="linuxvolumedrive_bulk_delete"),
+    path("linuxvolumedrive/<int:pk>/", LinuxVolumeDriveView.as_view(), name="linuxvolumedrive"),
+    path("linuxvolumedrive/<int:pk>/edit/", LinuxVolumeDriveEditView.as_view(), name="linuxvolumedrive_edit"),
+    path("linuxvolumedrive/<int:pk>/delete/", LinuxVolumeDriveDeleteView.as_view(), name="linuxvolumedrive_delete"),
     path(
-        "windowsvolume/<int:pk>/changelog/",
+        "linuxvolumedrive/<int:pk>/changelog/",
         ObjectChangeLogView.as_view(),
-        name="windowsvolume_changelog",
-        kwargs={"model": WindowsVolume},
+        name="linuxvolume_changelog",
+        kwargs={"model": LinuxVolumeDrive},
     ),
 ]
